Skip to contents

Helper Function: Get Package Name

Usage

get_pkgname(pkgname = NULL)

Arguments

pkgname

either package name or NULL. In the latter case the DESCRIPTION file in the current working directory is read and the package name from there is used (default: NULL)

Value

package name