Generates an index.md (used by pkgdown::build_home()) with the
KWB default badge set (GitHub Actions, codecov, lifecycle, CRAN, R-universe),
the package description from DESCRIPTION and an installation snippet.
Arguments
- user
user name or organisation under which the repository is hosted (default: "KWB-R")
- domain
under which the repository is hosted (default: "github")
- stage
badge declaring the developmental stage of the package according to https://www.tidyverse.org/lifecycle/; valid values are "experimental", "maturing", "stable", "retired", "archived", "dormant", "questioning" (default: "experimental")